@@ -6,7 +6,7 @@ Arg &Arg::initialize(char const *optstring,
                 int argc, char **argv)
 {
     if (s_arg)
-        throw Errno("Arg::initialize(): already initialized");
+        throw Exception() << "Arg::initialize(): already initialized";
 
     s_arg = new Arg(optstring, begin, end, argc, argv);
 
