@@ -1,6 +1,6 @@
 #include "arg.ih"
 
-size_t Arg::option(size_t idx, string *value, int optChar) const
+size_t Arg__::option(size_t idx, string *value, int optChar) const
 {
     ISVMapIterator it = d_optv.find(optChar);
     if (it == d_optv.end())
@@ -13,3 +13,8 @@ size_t Arg::option(size_t idx, string *value, int optChar) const
     
     return ret;                         // return this option count.
 }
+
+size_t Arg::option(size_t idx, string *value, int optChar) const
+{
+    return d_ptr->option(idx, value, optChar);
+}
