@@ -1,6 +1,6 @@
 #include "arg.ih"
 
-size_t Arg::option(size_t idx, 
+size_t Arg__::option(size_t idx, 
                  string *value, char const *longOption) const
 {
     SSVMapIterator it = d_longOptv.find(longOption);
@@ -14,3 +14,9 @@ size_t Arg::option(size_t idx,
     
     return ret;                         // return this option count.
 }
+
+size_t Arg::option(size_t idx, 
+                 string *value, char const *longOption) const
+{
+    return d_ptr->option(idx, value, longOption);
+}
