@@ -3,5 +3,5 @@
 void BigInt::copy(BIGNUM *lhs, BIGNUM const &rhs)
 {
     if (!BN_copy(lhs, &rhs))
-        throw Errno("BigInt: copying BigInt failed");
+        throw Exception() << "BigInt: copying BigInt failed";
 }
