@@ -1,6 +1,6 @@
 #include "bigint.ih"
 
-BigInt const BigInt::divc(BigInt *remainder, BigInt const &rhs) const
+BigInt BigInt::divc(BigInt *remainder, BigInt const &rhs) const
 {
     BigInt ret(*this);
     checked3(&ret.d_bn, &remainder->d_bn, rhs, "div");
