@@ -3,7 +3,7 @@
 BigInt &BigInt::lshift()
 {
     if (!BN_lshift1(&d_bn, &d_bn))
-        throw Errno("BigInt::lshift() failed");
+        throw Exception() << "BigInt::lshift() failed";
 
     return *this;
 }
