@@ -3,7 +3,7 @@
 BigInt &BigInt::lshift(size_t nBits)
 {
     if (!BN_lshift(&d_bn, &d_bn, nBits))
-        throw Errno("BigInt::lshift(size_t) failed");
+        throw Exception() << "BigInt::lshift(size_t) failed";
 
     return *this;
 }
