@@ -3,7 +3,7 @@
 namespace FBB
 {
 
-BigInt const operator<<(BigInt const &lhs, size_t nBits)
+BigInt operator<<(BigInt const &lhs, size_t nBits)
 {
     BigInt tmp(lhs);
     tmp <<= nBits;
