@@ -3,7 +3,7 @@
 BigInt &BigInt::rshift(size_t nBits)
 {
     if (!BN_rshift(&this->d_bn, &this->d_bn, nBits))
-        throw Errno("BigInt::rshift(size_t) failed");
+        throw Exception() << "BigInt::rshift(size_t) failed";
 
     return *this;
 }
