@@ -1,6 +1,6 @@
 #include "bigint.ih"
 
-BigInt const BigInt::setBigEndian(std::string const &bytes)
+BigInt BigInt::setBigEndian(std::string const &bytes)
 {
     BigInt tmp;
     BN_bin2bn(reinterpret_cast<unsigned char const *>(bytes.data()), 
