@@ -16,7 +16,8 @@ Cidr::MaskPair Cidr::parse(string const &cidr)
     {
         ret.second = A2x(cidr.substr(pos + 1));
         if (A2x::lastFail())
-            throw Errno(1, "Cidr: ") << "invalid CIDR: `" << cidr << '\'';
+            throw Exception(1) << "Cidr: " << "invalid CIDR: `" << 
+                                    cidr << '\'';
         ret.first = ret.first >> (32 - ret.second) << (32 - ret.second);
     }
 
