@@ -2,10 +2,8 @@
 
 int ClientSocket::connect()
 {
-    verify();               // verify the SocketBase construction
-
     if (::connect(socket(), sockaddrPtr(), size()) < 0)
-        throw Errno("ClientSocket::connect()");
+        throw Exception() << "ClientSocket::connect(): " << errnodescr;
 
     return socket();
 }
