@@ -3,10 +3,10 @@
 // "Wed Jun 30 21:49:08 1993\n"
 //  0                       ^
 //                          24 
-namespace std
+namespace FBB
 {
 
-ostream &operator<<(ostream &out, DateTime const &dt)
+std::ostream &operator<<(std::ostream &out, DateTime const &dt)
 {
     char buf[26];           // Magical number provided by ctime's man-page
 
