@@ -12,7 +12,7 @@ void DecryptBuf::done()
                             reinterpret_cast<unsigned char *>(d_pimpl->out), 
                             &outLen)
     )
-        throw Errno("Padding incorrect");
+        throw Exception() << "Padding incorrect";
 
     d_pimpl->outStream.write(d_pimpl->out, outLen);
     d_pimpl->active = false;
