@@ -9,5 +9,5 @@ void DecryptBuf::installKey(string const &key, size_t numberOfBytes)
         !EVP_EncryptInit_ex(&d_pimpl->ctx, 0, 0,
             reinterpret_cast<unsigned char const *>(key.data()), 0)
     )
-        throw Errno(1, "Couldn't set Key");
+        throw Exception(1) << "Couldn't set Key";
 }
