@@ -42,6 +42,6 @@ try
 }
 catch(Errno const &err)
 {
-    cout << err.what() << endl;
+    cout << err.why() << endl;
     return 1;
 }
