@@ -3,7 +3,7 @@
 void EncryptBuf::setKey(string key, size_t numberOfBytes)
 {
     if (d_pimpl->active)
-        throw Errno(1, "Can't change Key during encryption");
+        throw Exception(1) << "Can't change Key during encryption";
 
     if (numberOfBytes == 0)
         numberOfBytes = key.length();
