@@ -36,7 +36,7 @@ int main(int argc, char **argv, char **envp)
     }
     catch (Errno const &err)
     {
-        cout << err.what() << endl;
+        cout << err.why() << endl;
         return 1;
     }
     return 0;
