@@ -4,14 +4,18 @@
 
 #include <iostream>
 #include <string>
-#include <bobcat/glob>
+
 #include <bobcat/errno>
 
+#include "../glob"
+
+
 using namespace std;
 using namespace FBB;
 
 Glob makeGlob(char const *pat)
 {
+    cout << "Using pattern " << pat << '\n';
     return Glob(pat, Glob::PERIOD, Glob::DEFAULT);
 }
 
@@ -28,6 +32,7 @@ try
 
     Glob general;
 
+
     for (size_t idx = 0; idx < general.size(); idx++)
         cout << idx << ": " << general[idx] << '\n';
 
@@ -40,7 +45,18 @@ try
     for (size_t idx = 0; idx < pattern.size(); idx++)
         cout << idx << ": " << pattern[idx] << '\n';
 
-    cout << "\nThe next glob will fail, this is intended behavior\n";
+    pattern = Glob(Glob::DIRECTORY, argv[1], Glob::PERIOD, Glob::FIRST);
+    cout << "Only directories:\n";
+    for (size_t idx = 0; idx < pattern.size(); idx++)
+        cout << idx << ": " << pattern[idx] << '\n';
+
+    pattern = Glob(Glob::REGULAR_FILE, argv[1], Glob::PERIOD, Glob::FIRST);
+    cout << "regular files:\n";
+    for (size_t idx = 0; idx < pattern.size(); idx++)
+        cout << idx << ": " << pattern[idx] << '\n';
+
+
+    cout << "\nThe next glob fails, this is intentional\n";
 
     Glob fails("*", 1023);
 
@@ -51,3 +67,4 @@ catch (Errno const &err)
     cout << err.why() << '\n';
     return err.which();
 }
+
