@@ -39,7 +39,7 @@ int main(int argc, char **argv)
         }
         catch (Errno const &err)
         {
-            cout << err.what() << endl;
+            cout << err.why() << endl;
         }
     }
     return 0;
