@@ -17,7 +17,7 @@ int main(int argc, char **argv, char **envp)
     }
     catch(Errno const &e)
     {
-        cout << e.what() << endl;
+        cout << e.why() << endl;
     }
 
 
