@@ -3,5 +3,5 @@
 void Log::init()
 {
     d_level = 0;
-    d_activeLevel = UINT_MAX;
+    d_activeLevel = numeric_limits<size_t>::max();
 }
