@@ -10,10 +10,10 @@ std::ostream &flush(std::ostream &os)
     if (Mstream *mp = dynamic_cast<Mstream *>(&os))
     {
         if (mp->throws())
-            throw Errno(mp->id());
+            throw Exception() << mp->id();
 
         if (mp->lineExcess())
-            throw Errno(mp->id()) << "Exceeding max. # of " << 
+            throw Exception() << mp->id() << "Exceeding max. # of " << 
                         mp->maxCount() << " messages";
     }
     return os;
