@@ -7,13 +7,8 @@ int MultiStreambuf::pSync()
 
     Insert istruct = {d_buffer, true};
 
-    for_each(
-        d_os.begin(), d_os.end(), 
-        [&](stream &os)
-        {
-            insertStruct(os, istruct);
-        }
-    );
+    for (auto &os: d_os)
+        insertStruct(os, istruct);
 
     d_buffer.erase();
     return istruct.ok ? 0 : 1;
