@@ -2,5 +2,6 @@
 
 void MultiStreambuf::setOnce() 
 {
-    for_each(d_os.begin(), d_os.end(), &stream::setOnce);
+    for (auto &os: d_os)
+        stream::setOnce(os);
 }
