@@ -5,11 +5,11 @@ OneKey::OneKey(Mode state)
     setEcho(state);
 
     if (!isatty(STDIN_FILENO))
-        throw Errno(2, "OneKey::OneKey(): STDIN is not a tty");
+        throw Exception(2) << "OneKey::OneKey(): STDIN is not a tty";
 
     if (tcgetattr(STDIN_FILENO, &d_saved))
-        throw Errno(2, 
-                "OneKey::OneKey(): can't save the current stdin state");
+        throw Exception(2) <<
+                "OneKey::OneKey(): can't save the current stdin state";
     
     termios tattr;
 
@@ -22,7 +22,7 @@ OneKey::OneKey(Mode state)
     if (tcsetattr(STDIN_FILENO, TCSAFLUSH, &tattr))
     {
         tcsetattr(STDIN_FILENO, TCSANOW, &d_saved);
-        throw Errno(1, 
-            "OneKey::OneKey(): can't change the stdin state to direct input");
+        throw Exception(1) << 
+            "OneKey::OneKey(): can't change the stdin state to direct input";
     }
 }
