@@ -47,7 +47,7 @@ try
 }
 throw (Errno const &err)
 {
-    cout << err.what() << endl;
+    cout << err.why() << endl;
     return 1;
 }
 
