@@ -1,11 +1,11 @@
 #include "process.ih"
 
-void Process::showMode(char const *lab)
+void Process::showMode(char const *lab) const
 {
     std::cerr << lab << ' ' << getpid() << ' ' << d_child.pid << " IOMode: ";
 
-    if (d_mode & STD)
-        std::cerr << "STD ";
+    if (d_mode == NONE)
+        std::cerr << "NONE ";
     if (d_mode & CIN)
         std::cerr << "CIN ";
     if (d_mode & COUT)
@@ -31,3 +31,11 @@ void Process::showMode(char const *lab)
     std::cerr << '\n';
 }
 
+
+
+
+
+
+
+
+
