@@ -3,7 +3,7 @@
 void Redirector::through(int alternateFd) const
 {
     if (dup2(d_fd, alternateFd) < 0)
-        throw Errno("Redirector::through()");
+        throw Exception() << "Redirector::through(): " << errnodescr;
 
     ::close(d_fd);
 }
