@@ -6,7 +6,8 @@ SocketBase::SocketBase(string const &host, uint16_t port)
 {
     d_sock = ::socket(AF_INET, SOCK_STREAM, 0);   // 0: protocol, should be 0 
     if (d_sock < 0) 
-        throw Errno(1, "SocketBase::SocketBase(host, port)");
+        throw Exception() << "SocketBase::SocketBase(" << host << ", " << 
+                                            port << "): " << errnodescr;
 }
 
 
