@@ -1,9 +1,9 @@
 #include "string.ih"
 
-String::const_iterator String::quoted(string const &str,
-                                    const_iterator from, int quote)
+String::ConstIter String::quoted(string const &str,
+                                    ConstIter from, int quote)
 {
-    const_iterator beyond = str.end();
+    ConstIter beyond = str.end();
 
     while (true)
     {
